# Changelog

## [1.0.0-alpha.4](https://github.com/spdcalc/spdcalc-py/compare/0.1.0-alpha.4...v1.0.0-alpha.4) (2024-10-22)


### ⚠ BREAKING CHANGES

* remove elliptical waist support

### Bug Fixes

* remove elliptical waist support ([74d36e4](https://github.com/spdcalc/spdcalc-py/commit/74d36e46ecb0175f785751d6d6dbadc06f1933b9))
